Cerberus.Browser.Native (cerberus v0.1.7)

Copy Markdown View Source

Opaque browser unwrap handle returned by Cerberus.unwrap/2.

This is an escape hatch for advanced debugging and migration scenarios. It intentionally exposes a minimal surface and is not a stable low-level browser driver contract.

Summary

Functions

Returns the active browser tab id for this unwrap handle.

Returns the browser user-context process identifier for this unwrap handle.

Types

t()

@opaque t()

Functions

tab_id(native)

@spec tab_id(t()) :: String.t()

Returns the active browser tab id for this unwrap handle.

user_context_pid(native)

@spec user_context_pid(t()) :: pid()

Returns the browser user-context process identifier for this unwrap handle.