Installs Chrome for Testing and matching ChromeDriver, then prints a stable output payload for downstream config handoff.
mix cerberus.install.chrome
mix cerberus.install.chrome --version 146.0.7680.31
Installs Chrome for Testing and matching ChromeDriver, then prints a stable output payload for downstream config handoff.
mix cerberus.install.chrome
mix cerberus.install.chrome --version 146.0.7680.31